# yacman

[![Build Status](https://travis-ci.org/databio/yacman.svg?branch=master)](https://travis-ci.org/databio/yacman)

Yacman is a YAML configuration manager. It provides some convenience tools for dealing with YAML configuration files.

